#!/bin/bash
# This is a script to build a Zenwalk package. Check the Zenwalk homepage: www.zenwalk.org
#
# SOFTWARE			: libnxml
# PROJECT HOMEPAGE 	: http://www.autistici.org/bakunin/codes.php
# SOURCES          	: http://www.autistici.org/bakunin/libnxml/
#
# MAINTAINER       	: skywatcher (s.skywatcher|AT|gmail|DOT|org, simone antoniucci)
# LATEST REVISION	: 2009-03-22
#
# BUILD-ONLY DEPS	: -
# NOTES				: -

### Checking for unbound variables
set -u

### Setting main variables
NAME="libnxml"
VERSION="0.18.3"
ARCH="i486"
CPU="i686"
BUILD=62.1

HOMEPAGE="http://www.autistici.org/bakunin/codes.php"
DESCRIPTION="C library for managing XML"
SRCLNK="http://www.autistici.org/bakunin/libnxml/$NAME-$VERSION.tar.gz"

CWD=`pwd`
PKGDIR=$CWD/$NAME-install
PKG=$NAME-$VERSION-$ARCH-$BUILD
SRCPKG=`echo $SRCLNK | rev | cut -d/ -f1 | rev`
SRCDIR=$CWD/$NAME-$VERSION

URL=http://zenwalk.pinguix.com/user-accounts/skywatcher/$NAME/$VERSION
DOCS="AUTHORS ChangeLog COPYING INSTALL NEWS README"

NJOBS="-j2"
export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
export CXXFLAGS="-O2 -march=$ARCH -mtune=$CPU"

### Cleaning
rm -rf $PKGDIR
rm -rf $SRCDIR

### Mkdir
mkdir -p $PKGDIR
mkdir -p $PKGDIR/install
mkdir -p $PKGDIR/usr/doc/$NAME-$VERSION
mkdir -p $PKGDIR/usr/src/$NAME-$VERSION

### Checking if sources are present. If not, download them
if [ -f $SRCPKG ]; then
	echo "Source file is already present, no need to download it";
else
	echo "Downloading source..."
	wget -c -nv $SRCLNK
fi

### Extracting source
tar xfv $SRCPKG

### Building
cd $SRCDIR
./configure --prefix=/usr --sysconfdir=/etc --localstatedir=/var --mandir=/usr/man || exit 1
make $NJOBS || exit 1
make install DESTDIR=$PKGDIR || exit 1

### Stripping binaries
cd $PKGDIR
find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

### Docs, man, info
cd $SRCDIR
cp -av $DOCS $PKGDIR/usr/doc/$NAME-$VERSION
find $PKGDIR/usr/man -type f -exec gzip -9 {} \;

### Adding build-file and other stuff to the package
cp -av $CWD/$0 $PKGDIR/usr/src/$NAME-$VERSION/build-$NAME.sh
chmod a+x -v $PKGDIR/usr/src/$NAME-$VERSION/build-$NAME.sh

### Additional stuff

### Slack-desc 
#    |-----handy-ruler------------------------------------------------------|
cat > $PKGDIR/install/slack-desc << EOF
$NAME: $NAME - $DESCRIPTION
$NAME:  
$NAME: nXML is a C library for parsing, writing and creating XML 1.0 and
$NAME: 1.1 files or streams. It supports utf-8, utf-16be and utf-16le, 
$NAME: ucs-4 (1234, 4321, 2143, 2312).
$NAME: 
$NAME: 
$NAME: 
$NAME: 
$NAME: 
$NAME: $HOMEPAGE
EOF

### Ownerships and permissions
cd $PKGDIR
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

### Making the package
makepkg -l y -c n $CWD/$PKG.tgz

### md5
cd $CWD
md5sum $PKG.tgz > $PKG.md5

### dep
depfinder $PKG.tgz > $PKG.dep

### txt
cat $PKGDIR/install/slack-desc > $PKG.txt

### src
rm -fr $PKG.src
for link in $URL/$0 $SRCLNK
	do echo $link >> $PKG.src
done

### Cleaning
rm -rf $SRCDIR
rm -rf $PKGDIR

### Done. Ciao!
